"use client"
import { faChevronDown } from "@fortawesome/free-solid-svg-icons";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { Menu, Transition } from "@headlessui/react";
import { Fragment } from "react";
import { mergeClassNames } from "@/helpers";
import Link from "next/link";


interface IMenuItems {
	title: string,
	href: string,
	description?: string,
	target?: string

}
interface IDropdownProps {
	title: string
	menuItems: IMenuItems[]
	activeClassName?: string
	titleClassName?: string
}

export default function ButtonDropdown({ title, menuItems, activeClassName, titleClassName = "text-white" }: IDropdownProps) {
	return (
		<Menu as="div" className={"relative inline-block navlink " + activeClassName}>
			<div>
				<Menu.Button className={" font-semibold font-montserrat flex items-center " + titleClassName}>
					<span className="capitalize font-black text-[18px] lg:text-[14px] lg:font-extrabold">{title}</span> &nbsp;
					<FontAwesomeIcon
						id="downDropIcon"
						icon={faChevronDown}
						className={" h-4 w-4 inline "}
						aria-hidden="true"
					/>
				</Menu.Button>
			</div>

			<Transition
				as={Fragment}
				enter="transition ease-out duration-100"
				enterFrom="transform opacity-0 scale-95"
				enterTo="transform opacity-100 scale-100"
				leave="transition ease-in duration-75"
				leaveFrom="transform opacity-100 scale-100"
				leaveTo="transform opacity-0 scale-95"
			>
				<Menu.Items id="dropDownItems" className="absolute left-0 min-w-max mt-3 rounded-md space-y-1 focus:outline-none bg-rfw-dark px-4">
					{menuItems.map((menuItem) => (
						<div
							key={menuItem.title}
							className="hover:bg-rfw-dark  p-2 rounded"
							title={menuItem.description}
						>
							<Menu.Item>
								<Link
									href={menuItem.href}
									target={menuItem.target}
									className={mergeClassNames(
										"block px-2 hover:text-rfw-summer  text-white capitalize"
									)}
								>
									{menuItem.title}
								</Link>
							</Menu.Item>
						</div>
					))}
				</Menu.Items>
			</Transition>
		</Menu>
	);
}

